@@ -272,23 +272,23 @@ IngredientsDialog::IngredientsDialog( TQWidget* parent, RecipeDB *db ) : TQWidge
 	unitList = new UnitList;
 
 	// Signals & Slots
-	connect( ingredientListView->listView(), SIGNAL( selectionChanged() ), this, SLOT( updateLists() ) );
-	connect( addIngredientButton, SIGNAL( clicked() ), list_view, SLOT( createNew() ) );
-	connect( addUnitButton, SIGNAL( clicked() ), this, SLOT( addUnitToIngredient() ) );
-	connect( removeUnitButton, SIGNAL( clicked() ), this, SLOT( removeUnitFromIngredient() ) );
-	connect( addWeightButton, SIGNAL( clicked() ), this, SLOT( addWeight() ) );
-	connect( removeWeightButton, SIGNAL( clicked() ), this, SLOT( removeWeight() ) );
-	connect( removeIngredientButton, SIGNAL( clicked() ), list_view, SLOT( remove
+	connect( ingredientListView->listView(), TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( updateLists() ) );
+	connect( addIngredientButton, TQ_SIGNAL( clicked() ), list_view, TQ_SLOT( createNew() ) );
+	connect( addUnitButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( addUnitToIngredient() ) );
+	connect( removeUnitButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( removeUnitFromIngredient() ) );
+	connect( addWeightButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( addWeight() ) );
+	connect( removeWeightButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( removeWeight() ) );
+	connect( removeIngredientButton, TQ_SIGNAL( clicked() ), list_view, TQ_SLOT( remove
 		         () ) );
-	connect( addPropertyButton, SIGNAL( clicked() ), this, SLOT( addPropertyToIngredient() ) );
-	connect( removePropertyButton, SIGNAL( clicked() ), this, SLOT( removePropertyFromIngredient() ) );
-	connect( propertiesListView->listView(), SIGNAL( executed( TQListViewItem* ) ), this, SLOT( insertPropertyEditBox( TQListViewItem* ) ) );
-	connect( propertiesListView->listView(), SIGNAL( selectionChanged() ), inputBox, SLOT( hide() ) );
-	connect( inputBox, SIGNAL( valueChanged( double ) ), this, SLOT( setPropertyAmount( double ) ) );
+	connect( addPropertyButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( addPropertyToIngredient() ) );
+	connect( removePropertyButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( removePropertyFromIngredient() ) );
+	connect( propertiesListView->listView(), TQ_SIGNAL( executed( TQListViewItem* ) ), this, TQ_SLOT( insertPropertyEditBox( TQListViewItem* ) ) );
+	connect( propertiesListView->listView(), TQ_SIGNAL( selectionChanged() ), inputBox, TQ_SLOT( hide() ) );
+	connect( inputBox, TQ_SIGNAL( valueChanged( double ) ), this, TQ_SLOT( setPropertyAmount( double ) ) );
 
-	connect( weightsListView->listView(), SIGNAL( doubleClicked( TQListViewItem*, const TQPoint &, int ) ), SLOT( itemRenamed( TQListViewItem*, const TQPoint &, int ) ) );
+	connect( weightsListView->listView(), TQ_SIGNAL( doubleClicked( TQListViewItem*, const TQPoint &, int ) ), TQ_SLOT( itemRenamed( TQListViewItem*, const TQPoint &, int ) ) );
 
-	connect( loadUsdaButton, SIGNAL( clicked() ), this, SLOT( openUSDADialog() ) );
+	connect( loadUsdaButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( openUSDADialog() ) );
 }
 
 
