@@ -417,7 +417,7 @@ RecipeInputDialog::RecipeInputDialog( TQWidget* parent, RecipeDB *db ) : TQVBox(
 	ratingListDisplayWidget = new KWidgetListbox(ratingsTab);
 	TQPushButton *addRatingButton = new TQPushButton(i18n("Add Rating..."),ratingsTab);
 
-	connect( addRatingButton, SIGNAL(clicked()), this, SLOT(slotAddRating()) );
+	connect( addRatingButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotAddRating()) );
 
 	// ------- END OF Recipe Ratings Tab -----------
 
@@ -464,41 +464,41 @@ RecipeInputDialog::RecipeInputDialog( TQWidget* parent, RecipeDB *db ) : TQVBox(
 	enableChangedSignal(); // Enables the signal "changed()"
 
 	// Connect signals & Slots
-	connect( changePhotoButton, SIGNAL( clicked() ), this, SLOT( changePhoto() ) );
-	connect( clearPhotoButton, SIGNAL( clicked() ), SLOT( clearPhoto() ) );
-	connect( upButton, SIGNAL( clicked() ), this, SLOT( moveIngredientUp() ) );
-	connect( downButton, SIGNAL( clicked() ), this, SLOT( moveIngredientDown() ) );
-	connect( removeButton, SIGNAL( clicked() ), this, SLOT( removeIngredient() ) );
-	connect( addButton, SIGNAL( clicked() ), ingInput, SLOT( addIngredient() ) );
-	connect( ingParserButton, SIGNAL( clicked() ), this, SLOT( slotIngredientParser() ) );
-	connect( photoLabel, SIGNAL( changed() ), this, SIGNAL( changed() ) );
-	connect( this, SIGNAL( changed() ), this, SLOT( recipeChanged() ) );
-	connect( yieldNumInput, SIGNAL( textChanged( const TQString & ) ), this, SLOT( recipeChanged() ) );
-	connect( yieldTypeEdit, SIGNAL( textChanged( const TQString & ) ), this, SLOT( recipeChanged() ) );
-	connect( prepTimeEdit, SIGNAL( valueChanged( const TQTime & ) ), SLOT( recipeChanged() ) );
-	connect( titleEdit, SIGNAL( textChanged( const TQString& ) ), this, SLOT( recipeChanged( const TQString& ) ) );
-	connect( instructionsEdit, SIGNAL( textChanged() ), this, SLOT( recipeChanged() ) );
-	connect( addCategoryButton, SIGNAL( clicked() ), this, SLOT( addCategory() ) );
-	connect( addAuthorButton, SIGNAL( clicked() ), this, SLOT( addAuthor() ) );
-	connect( titleEdit, SIGNAL( textChanged( const TQString& ) ), this, SLOT( prepTitleChanged( const TQString& ) ) );
-	connect( ingredientList, SIGNAL( itemRenamed( TQListViewItem*, const TQString &, int ) ), SLOT( syncListView( TQListViewItem*, const TQString &, int ) ) );
+	connect( changePhotoButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( changePhoto() ) );
+	connect( clearPhotoButton, TQ_SIGNAL( clicked() ), TQ_SLOT( clearPhoto() ) );
+	connect( upButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( moveIngredientUp() ) );
+	connect( downButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( moveIngredientDown() ) );
+	connect( removeButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( removeIngredient() ) );
+	connect( addButton, TQ_SIGNAL( clicked() ), ingInput, TQ_SLOT( addIngredient() ) );
+	connect( ingParserButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotIngredientParser() ) );
+	connect( photoLabel, TQ_SIGNAL( changed() ), this, TQ_SIGNAL( changed() ) );
+	connect( this, TQ_SIGNAL( changed() ), this, TQ_SLOT( recipeChanged() ) );
+	connect( yieldNumInput, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( recipeChanged() ) );
+	connect( yieldTypeEdit, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( recipeChanged() ) );
+	connect( prepTimeEdit, TQ_SIGNAL( valueChanged( const TQTime & ) ), TQ_SLOT( recipeChanged() ) );
+	connect( titleEdit, TQ_SIGNAL( textChanged( const TQString& ) ), this, TQ_SLOT( recipeChanged( const TQString& ) ) );
+	connect( instructionsEdit, TQ_SIGNAL( textChanged() ), this, TQ_SLOT( recipeChanged() ) );
+	connect( addCategoryButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( addCategory() ) );
+	connect( addAuthorButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( addAuthor() ) );
+	connect( titleEdit, TQ_SIGNAL( textChanged( const TQString& ) ), this, TQ_SLOT( prepTitleChanged( const TQString& ) ) );
+	connect( ingredientList, TQ_SIGNAL( itemRenamed( TQListViewItem*, const TQString &, int ) ), TQ_SLOT( syncListView( TQListViewItem*, const TQString &, int ) ) );
 
-	connect ( ingInput, SIGNAL( ingredientEntered(const Ingredient&) ), this, SLOT( addIngredient(const Ingredient&) ) );
-	connect ( ingInput, SIGNAL( headerEntered(const Element&) ), this, SLOT( addIngredientHeader(const Element&) ) );
+	connect ( ingInput, TQ_SIGNAL( ingredientEntered(const Ingredient&) ), this, TQ_SLOT( addIngredient(const Ingredient&) ) );
+	connect ( ingInput, TQ_SIGNAL( headerEntered(const Element&) ), this, TQ_SLOT( addIngredientHeader(const Element&) ) );
 
-	connect( propertyStatusLed, SIGNAL(clicked()), SLOT(updatePropertyStatus()) );
-	connect( propertyStatusDialog, SIGNAL(user1Clicked()), SLOT(updatePropertyStatus()) );
-	connect( propertyStatusButton, SIGNAL(clicked()), propertyStatusDialog, SLOT(show()) );
+	connect( propertyStatusLed, TQ_SIGNAL(clicked()), TQ_SLOT(updatePropertyStatus()) );
+	connect( propertyStatusDialog, TQ_SIGNAL(user1Clicked()), TQ_SLOT(updatePropertyStatus()) );
+	connect( propertyStatusButton, TQ_SIGNAL(clicked()), propertyStatusDialog, TQ_SLOT(show()) );
 
 	// Function buttons
-	connect ( saveButton, SIGNAL( clicked() ), this, SLOT( save() ) );
-	connect ( closeButton, SIGNAL( clicked() ), this, SLOT( closeOptions() ) );
-	connect ( showButton, SIGNAL( clicked() ), this, SLOT( showRecipe() ) );
-	connect ( resizeButton, SIGNAL( clicked() ), this, SLOT( resizeRecipe() ) );
-	connect ( spellCheckButton, SIGNAL( clicked() ), this, SLOT( spellCheck() ) );
-	connect ( this, SIGNAL( enableSaveOption( bool ) ), this, SLOT( enableSaveButton( bool ) ) );
+	connect ( saveButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( save() ) );
+	connect ( closeButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( closeOptions() ) );
+	connect ( showButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( showRecipe() ) );
+	connect ( resizeButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( resizeRecipe() ) );
+	connect ( spellCheckButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( spellCheck() ) );
+	connect ( this, TQ_SIGNAL( enableSaveOption( bool ) ), this, TQ_SLOT( enableSaveButton( bool ) ) );
 
-	connect ( database, SIGNAL( recipeRemoved(int) ), this, SLOT( recipeRemoved(int) ) );
+	connect ( database, TQ_SIGNAL( recipeRemoved(int) ), this, TQ_SLOT( recipeRemoved(int) ) );
 
 	delete il;
 
@@ -1373,10 +1373,10 @@ void RecipeInputDialog::addRating( const Rating &rating, RatingDisplayWidget *it
 
 	item->buttonEdit->disconnect();
 	item->buttonRemove->disconnect();
-	connect(item->buttonEdit, SIGNAL(clicked()),
-		this, SLOT(slotEditRating()));
-	connect(item->buttonRemove, SIGNAL(clicked()),
-		this, SLOT(slotRemoveRating()));
+	connect(item->buttonEdit, TQ_SIGNAL(clicked()),
+		this, TQ_SLOT(slotEditRating()));
+	connect(item->buttonRemove, TQ_SIGNAL(clicked()),
+		this, TQ_SLOT(slotRemoveRating()));
 }
 
 void RecipeInputDialog::slotEditRating()
