@@ -62,7 +62,7 @@ SetupDisplay::SetupDisplay( const Recipe &sample, TQWidget *parent ) : TDEHTMLPa
 		has_changes( false ),
 		popup(0)
 {
-	connect( this, SIGNAL( popupMenu(const TQString &,const TQPoint &) ), SLOT( nodeClicked(const TQString &,const TQPoint &) ) );
+	connect( this, TQ_SIGNAL( popupMenu(const TQString &,const TQPoint &) ), TQ_SLOT( nodeClicked(const TQString &,const TQPoint &) ) );
 
 	if ( sample.recipeID != -1 )
 		m_sample = sample;
@@ -420,16 +420,16 @@ void SetupDisplay::nodeClicked(const TQString &/*url*/,const TQPoint &point)
 	TDEIconLoader il;
 
 	if ( properties & BackgroundColor )
-		popup->insertItem( i18n( "Background Color..." ), this, SLOT( setBackgroundColor() ) );
+		popup->insertItem( i18n( "Background Color..." ), this, TQ_SLOT( setBackgroundColor() ) );
 
 	if ( properties & TextColor )
-		popup->insertItem( i18n( "Text Color..." ), this, SLOT( setTextColor() ) );
+		popup->insertItem( i18n( "Text Color..." ), this, TQ_SLOT( setTextColor() ) );
 
 	if ( properties & Font )
-		popup->insertItem( il.loadIconSet( "text", TDEIcon::Small, 16 ), i18n( "Font..." ), this, SLOT( setFont() ) );
+		popup->insertItem( il.loadIconSet( "text", TDEIcon::Small, 16 ), i18n( "Font..." ), this, TQ_SLOT( setFont() ) );
 
 	if ( properties & Visibility ) {
-		int id = popup->insertItem( i18n( "Show" ), this, SLOT( setShown( int ) ) );
+		int id = popup->insertItem( i18n( "Show" ), this, TQ_SLOT( setShown( int ) ) );
 		popup->setItemChecked( id, item->show );
 	}
 
@@ -451,7 +451,7 @@ void SetupDisplay::nodeClicked(const TQString &/*url*/,const TQPoint &point)
 		if ( align & TQt::AlignRight )
 			r_action->setOn(true);
 
-		connect( alignment_actions, SIGNAL( selected( TQAction* ) ), SLOT( setAlignment( TQAction* ) ) );
+		connect( alignment_actions, TQ_SIGNAL( selected( TQAction* ) ), TQ_SLOT( setAlignment( TQAction* ) ) );
 
 		popup->insertItem( i18n( "Alignment" ), sub_popup );
 
@@ -459,10 +459,10 @@ void SetupDisplay::nodeClicked(const TQString &/*url*/,const TQPoint &point)
 	}
 
 	if ( properties & Border )
-		popup->insertItem( i18n( "Border..." ), this, SLOT( setBorder() ) );
+		popup->insertItem( i18n( "Border..." ), this, TQ_SLOT( setBorder() ) );
 
 	if ( properties & Columns )
-		popup->insertItem( i18n( "Columns..." ), this, SLOT( setColumns() ) );
+		popup->insertItem( i18n( "Columns..." ), this, TQ_SLOT( setColumns() ) );
 
 	popup->popup( point );
 }
