@@ -24,7 +24,7 @@ class TDEListView;
 
 class USDADataDialog : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
 	USDADataDialog( const Element &, RecipeDB *database, TQWidget *parent = 0 );
