@@ -243,43 +243,43 @@ KrecipesView::KrecipesView( TQWidget *parent )
 
 
 	// Connect Signals from Left Panel to slotSetPanel()
-	connect( leftPanel, SIGNAL( clicked( KrePanel ) ), this, SLOT( slotSetPanel( KrePanel ) ) );
+	connect( leftPanel, TQ_SIGNAL( clicked( KrePanel ) ), this, TQ_SLOT( slotSetPanel( KrePanel ) ) );
 
-	connect( contextButton, SIGNAL( clicked() ), SLOT( activateContextHelp() ) );
+	connect( contextButton, TQ_SIGNAL( clicked() ), TQ_SLOT( activateContextHelp() ) );
 
-	connect( leftPanel, SIGNAL( resized( int, int ) ), this, SLOT( resizeRightPane( int, int ) ) );
+	connect( leftPanel, TQ_SIGNAL( resized( int, int ) ), this, TQ_SLOT( resizeRightPane( int, int ) ) );
 
 
 	// Retransmit signal to parent to Enable/Disable the Save Button
-	connect ( inputPanel, SIGNAL( enableSaveOption( bool ) ), this, SIGNAL( enableSaveOption( bool ) ) );
+	connect ( inputPanel, TQ_SIGNAL( enableSaveOption( bool ) ), this, TQ_SIGNAL( enableSaveOption( bool ) ) );
 
 	// Create a new button when a recipe is unsaved
-	connect ( inputPanel, SIGNAL( createButton( TQWidget*, const TQString & ) ), this, SLOT( addRecipeButton( TQWidget*, const TQString & ) ) );
+	connect ( inputPanel, TQ_SIGNAL( createButton( TQWidget*, const TQString & ) ), this, TQ_SLOT( addRecipeButton( TQWidget*, const TQString & ) ) );
 
 	// Connect Signals from selectPanel (SelectRecipeDialog)
 
-	connect ( selectPanel, SIGNAL( recipeSelected( int, int ) ), this, SLOT( actionRecipe( int, int ) ) );
-	connect ( selectPanel, SIGNAL( recipesSelected( const TQValueList<int>&, int ) ), this, SLOT( actionRecipes( const TQValueList<int>&, int ) ) );
+	connect ( selectPanel, TQ_SIGNAL( recipeSelected( int, int ) ), this, TQ_SLOT( actionRecipe( int, int ) ) );
+	connect ( selectPanel, TQ_SIGNAL( recipesSelected( const TQValueList<int>&, int ) ), this, TQ_SLOT( actionRecipes( const TQValueList<int>&, int ) ) );
 
 	// Connect Signals from ingredientMatcherPanel (IngredientMatcherDialog)
 
-	connect ( ingredientMatcherPanel, SIGNAL( recipeSelected( int, int ) ), SLOT( actionRecipe( int, int ) ) );
+	connect ( ingredientMatcherPanel, TQ_SIGNAL( recipeSelected( int, int ) ), TQ_SLOT( actionRecipe( int, int ) ) );
 
 	// Close a recipe when requested (just switch panels)
-	connect( inputPanel, SIGNAL( closeRecipe() ), this, SLOT( closeRecipe() ) );
+	connect( inputPanel, TQ_SIGNAL( closeRecipe() ), this, TQ_SLOT( closeRecipe() ) );
 
 	// Show a recipe when requested (just switch panels)
-	connect( inputPanel, SIGNAL( showRecipe( int ) ), this, SLOT( showRecipe( int ) ) );
+	connect( inputPanel, TQ_SIGNAL( showRecipe( int ) ), this, TQ_SLOT( showRecipe( int ) ) );
 
 	// Create a new shopping list when a new diet is generated and accepted
-	connect( dietPanel, SIGNAL( dietReady() ), this, SLOT( createShoppingListFromDiet() ) );
+	connect( dietPanel, TQ_SIGNAL( dietReady() ), this, TQ_SLOT( createShoppingListFromDiet() ) );
 
 	// Place the Tip Button in correct position when the left pane is resized
-	connect( leftPanel, SIGNAL( resized( int, int ) ), this, SLOT( moveTipButton( int, int ) ) );
+	connect( leftPanel, TQ_SIGNAL( resized( int, int ) ), this, TQ_SLOT( moveTipButton( int, int ) ) );
 
-	connect( rightPanel, SIGNAL( panelRaised( TQWidget*, TQWidget* ) ), SLOT( panelRaised( TQWidget*, TQWidget* ) ) );
+	connect( rightPanel, TQ_SIGNAL( panelRaised( TQWidget*, TQWidget* ) ), TQ_SLOT( panelRaised( TQWidget*, TQWidget* ) ) );
 
-	connect( selectPanel, SIGNAL( recipeSelected(bool) ), SIGNAL( recipeSelected(bool) ) );
+	connect( selectPanel, TQ_SIGNAL( recipeSelected(bool) ), TQ_SIGNAL( recipeSelected(bool) ) );
 
 	// Close Splash Screen
 	delete start_logo;
@@ -708,8 +708,8 @@ void KrecipesView::addRecipeButton( TQWidget *w, const TQString &title )
 		buttonsList->append( recipeButton );
 		leftPanel->highlightButton( recipeButton );
 
-		connect( recipeButton, SIGNAL( clicked() ), this, SLOT( switchToRecipe() ) );
-		connect( ( RecipeInputDialog * ) w, SIGNAL( titleChanged( const TQString& ) ), recipeButton, SLOT( setTitle( const TQString& ) ) );
+		connect( recipeButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( switchToRecipe() ) );
+		connect( ( RecipeInputDialog * ) w, TQ_SIGNAL( titleChanged( const TQString& ) ), recipeButton, TQ_SLOT( setTitle( const TQString& ) ) );
 	}
 
 }
