@@ -81,7 +81,7 @@ enum KrePanel {SelectP = 0, ShoppingP, DietP, MatcherP, IngredientsP, Properties
 // Class KrecipesView
 class KrecipesView : public TQVBox, virtual public KrecipesIface
 {
-	Q_OBJECT
+	TQ_OBJECT
 public:
 	/**
 	 * Default constructor
