@@ -81,7 +81,7 @@ KrecipesPreferences::KrecipesPreferences( TQWidget *parent )
 	m_helpMap.insert(3,"configure-performance");
 
 	// Signals & Slots
-	connect ( this, SIGNAL( okClicked() ), this, SLOT( saveSettings() ) );
+	connect ( this, TQ_SIGNAL( okClicked() ), this, TQ_SLOT( saveSettings() ) );
 
 }
 
