@@ -32,7 +32,7 @@ class RecipeDB;
   */
 class RecipeActionsHandler : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
 	enum ItemType { Category, Recipe };
