@@ -74,8 +74,8 @@ SetupWizard::SetupWizard( TQWidget *parent, const char *name, bool modal, WFlags
 		showPages( SQLite );
 	#endif
 
-	connect( finishButton(), SIGNAL( clicked() ), this, SLOT( save() ) );
-	connect( dbTypeSetupPage, SIGNAL( showPages( DBType ) ), this, SLOT( showPages( DBType ) ) );
+	connect( finishButton(), TQ_SIGNAL( clicked() ), this, TQ_SLOT( save() ) );
+	connect( dbTypeSetupPage, TQ_SIGNAL( showPages( DBType ) ), this, TQ_SLOT( showPages( DBType ) ) );
 
 }
 
@@ -210,9 +210,9 @@ PermissionsSetupPage::PermissionsSetupPage( TQWidget *parent ) : TQWidget( paren
 
 	// Connect Signals & slots
 
-	connect( rootCheckBox, SIGNAL( toggled( bool ) ), rootInfoGBox, SLOT( setEnabled( bool ) ) );
-	connect( rootCheckBox, SIGNAL( toggled( bool ) ), this, SLOT( rootCheckBoxChanged( bool ) ) );
-	connect( noSetupCheckBox, SIGNAL( toggled( bool ) ), this, SLOT( noSetupCheckBoxChanged( bool ) ) );
+	connect( rootCheckBox, TQ_SIGNAL( toggled( bool ) ), rootInfoGBox, TQ_SLOT( setEnabled( bool ) ) );
+	connect( rootCheckBox, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( rootCheckBoxChanged( bool ) ) );
+	connect( noSetupCheckBox, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( noSetupCheckBoxChanged( bool ) ) );
 }
 
 void PermissionsSetupPage::rootCheckBoxChanged( bool on )
@@ -318,9 +318,9 @@ PSqlPermissionsSetupPage::PSqlPermissionsSetupPage( TQWidget *parent ) : TQWidge
 
 	// Connect Signals & slots
 
-	connect( rootCheckBox, SIGNAL( toggled( bool ) ), rootInfoGBox, SLOT( setEnabled( bool ) ) );
-	connect( rootCheckBox, SIGNAL( toggled( bool ) ), this, SLOT( rootCheckBoxChanged( bool ) ) );
-	connect( noSetupCheckBox, SIGNAL( toggled( bool ) ), this, SLOT( noSetupCheckBoxChanged( bool ) ) );
+	connect( rootCheckBox, TQ_SIGNAL( toggled( bool ) ), rootInfoGBox, TQ_SLOT( setEnabled( bool ) ) );
+	connect( rootCheckBox, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( rootCheckBoxChanged( bool ) ) );
+	connect( noSetupCheckBox, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( noSetupCheckBoxChanged( bool ) ) );
 }
 
 void PSqlPermissionsSetupPage::rootCheckBoxChanged( bool on )
@@ -478,7 +478,7 @@ ServerSetupPage::ServerSetupPage( TQWidget *parent ) : TQWidget( parent )
 	//layout->addItem( spacerRight, 7, 4 );
 
 	// Signals & Slots
-	connect( remoteServerCheckBox, SIGNAL( toggled( bool ) ), serverSettingsGBox, SLOT( setEnabled( bool ) ) );
+	connect( remoteServerCheckBox, TQ_SIGNAL( toggled( bool ) ), serverSettingsGBox, TQ_SLOT( setEnabled( bool ) ) );
 
 }
 
@@ -569,7 +569,7 @@ SQLiteSetupPage::SQLiteSetupPage( TQWidget *parent ) : TQWidget( parent )
 	TQSpacerItem* bottomSpacer = new TQSpacerItem( 10, 10, TQSizePolicy::Minimum, TQSizePolicy::MinimumExpanding );
 	layout->addItem( bottomSpacer, 4, 1 );
 
-	connect( file_select, SIGNAL( clicked() ), SLOT( selectFile() ) );
+	connect( file_select, TQ_SIGNAL( clicked() ), TQ_SLOT( selectFile() ) );
 }
 
 TQString SQLiteSetupPage::dbFile( void ) const
@@ -810,14 +810,13 @@ DBTypeSetupPage::DBTypeSetupPage( TQWidget *parent ) : TQWidget( parent )
 	TQSpacerItem *spacer_bottom = new TQSpacerItem( 10, 10, TQSizePolicy::Fixed, TQSizePolicy::MinimumExpanding );
 	layout->addItem( spacer_bottom, 4, 3 );
 
-	connect( bg, SIGNAL( clicked( int ) ), this, SLOT( setPages( int ) ) );
+	connect( bg, TQ_SIGNAL( clicked( int ) ), this, TQ_SLOT( setPages( int ) ) );
 
 }
 
 int DBTypeSetupPage::dbType( void )
 {
-	//int id=bg->selectedId(); //QT 3.2
-	int id = bg->id( bg->selected() ); //QT 3.1
+	int id = bg->id( bg->selected() );
 
 	switch ( id ) {
 	case 1:
